LangService class

Constructors

LangService()
factory

Properties

currentLang String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

changeLang(String langCode) Future<void>
init() Future<void>
loadTranslations(String langCode) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
tr(String key, {Map<String, String>? params}) String

Operators

operator ==(Object other) bool
The equality operator.
inherited